@@ -17,7 +17,7 @@
     use constant _MATH_MPC_T    => 10;
 
 use subs qw( __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
-             __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS);
+             __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS GMP_LIMB_BITS GMP_NAIL_BITS);
 
 use overload
     '++'   => \&overload_inc,
@@ -57,6 +57,7 @@ Rmpq_set Rmpq_set_d Rmpq_set_den Rmpq_set_f Rmpq_set_num Rmpq_set_si Rmpq_set_st
 Rmpq_set_ui Rmpq_set_z Rmpq_sgn
 Rmpq_sprintf Rmpq_snprintf
 Rmpq_sub Rmpq_swap
+Rmpq_integer_p
 TRmpq_out_str TRmpq_inp_str
 qgmp_randseed qgmp_randseed_ui qgmp_randclear
 qgmp_randinit_default qgmp_randinit_mt qgmp_randinit_lc_2exp qgmp_randinit_lc_2exp_size
@@ -64,7 +65,7 @@ qgmp_randinit_set qgmp_randinit_default_nobless qgmp_randinit_mt_nobless
 qgmp_randinit_lc_2exp_nobless qgmp_randinit_lc_2exp_size_nobless qgmp_randinit_set_nobless
 qgmp_urandomb_ui qgmp_urandomm_ui
     );
-    our $VERSION = '0.38';
+    our $VERSION = '0.39';
     #$VERSION = eval $VERSION;
 
     DynaLoader::bootstrap Math::GMPq $VERSION;
@@ -81,6 +82,7 @@ Rmpq_set Rmpq_set_d Rmpq_set_den Rmpq_set_f Rmpq_set_num Rmpq_set_si Rmpq_set_st
 Rmpq_set_ui Rmpq_set_z Rmpq_sgn
 Rmpq_sprintf Rmpq_snprintf
 Rmpq_sub Rmpq_swap
+Rmpq_integer_p
 TRmpq_out_str TRmpq_inp_str
 qgmp_randseed qgmp_randseed_ui qgmp_randclear
 qgmp_randinit_default qgmp_randinit_mt qgmp_randinit_lc_2exp qgmp_randinit_lc_2exp_size
@@ -270,6 +272,8 @@ sub __GNU_MP_VERSION_PATCHLEVEL {return ___GNU_MP_VERSION_PATCHLEVEL()}
 sub __GNU_MP_RELEASE {return ___GNU_MP_RELEASE()}
 sub __GMP_CC {return ___GMP_CC()}
 sub __GMP_CFLAGS {return ___GMP_CFLAGS()}
+sub GMP_LIMB_BITS {return _GMP_LIMB_BITS()}
+sub GMP_NAIL_BITS {return _GMP_NAIL_BITS()}
 
 *qgmp_randseed =                      \&Math::GMPq::Random::Rgmp_randseed;
 *qgmp_randseed_ui =                   \&Math::GMPq::Random::Rgmp_randseed_ui;
@@ -805,6 +809,15 @@ __END__
        deemed to be of an invalid type. The subroutine croaks with
        an appropriate error message.
 
+   ##############
+
+   MISCELLANEOUS
+
+   $bool = Rmpq_integer_p($op);
+    Returns true if $op is an integer (ie denominator of $op is 1).
+    Else returns false. The mpq_integer_p function is not
+    implemented in gmp.
+
    #####
 
    OTHER
@@ -922,7 +935,7 @@ __END__
 
     This program is free software; you may redistribute it and/or
     modify it under the same terms as Perl itself.
-    Copyright 2006-2011, 2013-14, Sisyphus
+    Copyright 2006-2011, 2013-16, Sisyphus
 
 =head1 AUTHOR
 
